pub enum DiffBaseArg {
LastTurn,
}Expand description
Named bases shared by diff and review change selection.
Variants
LastTurn
First capture in the current harness session on this thread.
Implementations