pub struct DiscussNewArgs {
pub scope: CodeScopeArgs,
pub revision: HistoricalRevisionArgs,
pub message: AuthoredMessageArgs,
pub title: Option<String>,
pub visibility: Option<String>,
pub thread: Option<String>,
}Fields
scope: CodeScopeArgsrevision: HistoricalRevisionArgsmessage: AuthoredMessageArgstitle: Option<String>Human-readable summary. Defaults to the first line of the first turn.
visibility: Option<String>Visibility: public | internal | team:NAME | restricted:LABEL | private:LABEL.
thread: Option<String>Attach the discussion to a thread ref while keeping its code anchor.