pub struct TimelineTargetArgs {
pub thread: String,
pub from_branch: Option<String>,
pub step: Option<String>,
pub tool_call: Option<String>,
pub harness: String,
pub session: Option<String>,
pub message: Option<String>,
pub undo: bool,
pub redo: bool,
pub current: bool,
}Expand description
Shared selector arguments for timeline action commands.
Fields
thread: StringTimeline thread to target.
from_branch: Option<String>Constrain the target to this branch when selecting by step/current cursor.
step: Option<String>Target a timeline step id.
tool_call: Option<String>Target a native harness tool call id, such as an OpenCode tool call id.
harness: StringNative harness name for --tool-call.
session: Option<String>Native harness session id for --tool-call.
message: Option<String>Native harness message id for --tool-call.
undo: boolTarget the previous step from the current cursor.
redo: boolTarget the next step from the current cursor.
current: boolTarget the current logical cursor.